==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/zh_CN.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "任务",
    "Due yesterday" : "昨日过期",
    "Due today" : "今日到期",
    "Due tomorrow" : "明日到期",
    "Due on" : "今日到期",
    "Started yesterday" : "昨天开始",
    "Starts today" : "今天开始",
    "Starts tomorrow" : "明天开始",
    "Started on" : "开始于",
    "Starts on" : "开始于",
    "[Remind me yesterday at ]HH:mm" : "[昨天提醒于 ]HH:mm",
    "[Remind me today at ]HH:mm" : "[今天提醒我 ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[明天提醒我 ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[提醒日期 ]YYYY-MM-DD, HH:mm",
    "Yesterday" : "昨天",
    "Today" : "今天",
    "Tomorrow" : "明天",
    "in %s" : "在 %s",
    "%s ago" : "%s 前",
    "seconds" : "秒",
    "a minute" : "一分钟",
    "%d minutes" : "%d 分钟",
    "an hour" : "一小时",
    "%d hours" : "%d 小时",
    "a day" : "一天",
    "%d days" : "%d 天",
    "a month" : "一个月",
    "%d months" : "%d 月",
    "a year" : "一年",
    "%d years" : "%d 年",
    "week" : "周",
    "weeks" : "周",
    "day" : "天",
    "days" : "天",
    "hour" : "小时",
    "hours" : "小时",
    "minute" : "分钟",
    "minutes" : "分钟",
    "second" : "第二",
    "before beginning" : "开始前",
    "after beginning" : "开始后",
    "before end" : "结束前",
    "after end" : "结束后",
    "Comment" : "评论",
    "Add a comment" : "添加评论",
    "This will delete the Calendar \"%s\" and all of its entries." : "这会删除日历 \"%s\" 和其中的所有内容。",
    "The name \"%s\" is already used." : "名称 \"%s\" 已被使用。",
    "An empty name is not allowed." : "不允许使用空名称。",
    "Hidden" : "隐藏",
    "Visible" : "可见",
    "Automatic" : "自动",
    "Sunday" : "星期日",
    "Monday" : "星期一",
    "Tuesday" : "星期二",
    "Wednesday" : "星期三",
    "Thursday" : "星期四",
    "Friday" : "星期五",
    "Saturday" : "星期六",
    "Add an important item in \"%s\"..." : "添加一个重要事项到 \"%s\"...",
    "Add an item due today in \"%s\"..." : "添加一个事项截止日期到 \"%s\"...",
    "Add an item in \"%s\"..." : "添加一个事项到 \"%s\"...",
    "Add a current item in \"%s\"..." : "添加当前事项到 \"%s\"...",
    "Add a subtask to \"%s\"..." : "添加子任务到 \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n 任务完成"],
    "Hours" : "小时",
    "Minutes" : "分钟",
    "Set due date" : "设置截止日期",
    "%s %% completed" : "%s %% 完成",
    "priority %s: " : "优先级 %s:",
    "high" : "高",
    "medium" : "中",
    "low" : "低",
    "no priority assigned" : "未设置优先级",
    "Remind me" : "提醒我",
    "at the end" : "于结尾",
    "at the beginning" : "于开始",
    "Set start date" : "设置开始日期",
    "{calendar} shared by {owner}" : "{calendar} 由 {owner} 共享",
    "Unnamed" : "未命名",
    "Important" : "重要",
    "Week" : "星期",
    "All" : "全部",
    "Current" : "当前",
    "Completed" : "完成",
    "Delete" : "删除",
    "Cancel" : "取消",
    "Edit" : "编辑",
    "Link" : "链接",
    "Download" : "下载",
    "Save" : "保存",
    "Add List..." : "添加列表",
    "New List" : "新列表",
    "Settings" : "设置",
    "Start of week" : "一周开始于",
    "Visibility of Smart Collections" : "智能集合的可见性",
    "Change sort order" : "更改排序",
    "Default" : "默认",
    "Due date" : "截止日期",
    "Start date" : "开始日期",
    "Priority" : "优先级",
    "Alphabetically" : "字母序",
    "Manually" : "手动",
    "Load remaining completed tasks." : "载入剩余的已完成任务。",
    "Task is completed" : "任务完成",
    "All day" : "所有天",
    "(New category)" : "（新分类）",
    "Select categories..." : "选择分类",
    "Loading the task..." : "读取任务中...",
    "Task not found!" : "没有任务！",
    "add a subtask to" : "添加子任务到",
    "Toggle subtasks" : "切换子任务",
    "Toggle completed subtasks" : "切换已完成的子任务"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.9.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/zh_CN.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "任务",
    "Due yesterday" : "昨日过期",
    "Due today" : "今日到期",
    "Due tomorrow" : "明日到期",
    "Due on" : "今日到期",
    "Started yesterday" : "昨天开始",
    "Starts today" : "今天开始",
    "Starts tomorrow" : "明天开始",
    "Started on" : "开始于",
    "Starts on" : "开始于",
    "[Remind me yesterday at ]HH:mm" : "[昨天提醒于 ]HH:mm",
    "[Remind me today at ]HH:mm" : "[今天提醒我 ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[明天提醒我 ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[提醒日期 ]YYYY-MM-DD, HH:mm",
    "Yesterday" : "昨天",
    "Today" : "今天",
    "Tomorrow" : "明天",
    "in %s" : "在 %s",
    "%s ago" : "%s 前",
    "seconds" : "秒",
    "a minute" : "一分钟",
    "%d minutes" : "%d 分钟",
    "an hour" : "一小时",
    "%d hours" : "%d 小时",
    "a day" : "一天",
    "%d days" : "%d 天",
    "a month" : "一个月",
    "%d months" : "%d 月",
    "a year" : "一年",
    "%d years" : "%d 年",
    "week" : "周",
    "weeks" : "周",
    "day" : "天",
    "days" : "天",
    "hour" : "小时",
    "hours" : "小时",
    "minute" : "分钟",
    "minutes" : "分钟",
    "second" : "第二",
    "before beginning" : "开始前",
    "after beginning" : "开始后",
    "before end" : "结束前",
    "after end" : "结束后",
    "Comment" : "评论",
    "Add a comment" : "添加评论",
    "The name \"%s\" is already used." : "名称 \"%s\" 已被使用。",
    "An empty name is not allowed." : "不允许使用空名称。",
    "Hidden" : "隐藏",
    "Visible" : "可见",
    "Automatic" : "自动",
    "Sunday" : "星期日",
    "Monday" : "星期一",
    "Tuesday" : "星期二",
    "Wednesday" : "星期三",
    "Thursday" : "星期四",
    "Friday" : "星期五",
    "Saturday" : "星期六",
    "Add an important item in \"%s\"..." : "添加一个重要事项到 \"%s\"...",
    "Add an item due today in \"%s\"..." : "添加一个事项截止日期到 \"%s\"...",
    "Add an item in \"%s\"..." : "添加一个事项到 \"%s\"...",
    "Add a current item in \"%s\"..." : "添加当前事项到 \"%s\"...",
    "Add a subtask to \"%s\"..." : "添加子任务到 \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n 任务完成"],
    "Hours" : "小时",
    "Minutes" : "分钟",
    "Set due date" : "设置截止日期",
    "%s %% completed" : "%s %% 完成",
    "priority %s: " : "优先级 %s:",
    "high" : "高",
    "medium" : "中",
    "low" : "低",
    "no priority assigned" : "未设置优先级",
    "Remind me" : "提醒我",
    "at the end" : "于结尾",
    "at the beginning" : "于开始",
    "Set start date" : "设置开始日期",
    "{calendar} shared by {owner}" : "{calendar} 由 {owner} 共享",
    "Unnamed" : "未命名",
    "Important" : "重要",
    "Week" : "星期",
    "All" : "全部",
    "Current" : "当前",
    "Completed" : "完成",
    "The Tasks app for Nextcloud" : "Nextcloud 任务应用",
    "Delete" : "删除",
    "Cancel" : "取消",
    "Edit" : "编辑",
    "Link" : "链接",
    "Download" : "下载",
    "Save" : "保存",
    "Add List..." : "添加列表",
    "New List" : "新列表",
    "Settings" : "设置",
    "Start of week" : "一周开始于",
    "Visibility of Smart Collections" : "智能集合的可见性",
    "Change sort order" : "更改排序",
    "Default" : "默认",
    "Due date" : "截止日期",
    "Start date" : "开始日期",
    "Priority" : "优先级",
    "Alphabetically" : "字母序",
    "Manually" : "手动",
    "Load remaining completed tasks." : "载入剩余的已完成任务。",
    "Task is completed" : "任务完成",
    "All day" : "所有天",
    "(New category)" : "（新分类）",
    "Select categories..." : "选择分类",
    "Loading the task..." : "读取任务中...",
    "Task not found!" : "没有任务！",
    "add a subtask to" : "添加子任务到",
    "Toggle subtasks" : "切换子任务",
    "Toggle completed subtasks" : "切换已完成的子任务"
},
"nplurals=1; plural=0;");
